@@ -114,6 +114,14 @@ bool MariaRow::is_null(int j) {
   return nulls_[j] == 1;
 }
 
+int MariaRow::value_bool(int j) {
+  if (is_null(j)) {
+    return NA_LOGICAL;
+  } else {
+    return static_cast<int>(value_int(j) == 1);
+  }
+}
+
 int MariaRow::value_int(int j) {
   return is_null(j) ? NA_INTEGER : *((int*) &buffers_[j][0]);
 }
@@ -214,7 +222,7 @@ void MariaRow::set_list_value(SEXP x, int i, int j) {
     SET_VECTOR_ELT(x, i, value_raw(j));
     break;
   case MY_LGL:
-    LOGICAL(x)[i] = value_int(j) ? 1 : 0;
+    LOGICAL(x)[i] = value_bool(j);
     break;
   }
 }
