@@ -3,7 +3,7 @@
 
 #define INT64SXP REALSXP
 
-#define NA_INTEGER64 (0x8000000000000000)
+#define NA_INTEGER64 (static_cast<int64_t>(0x8000000000000000))
 
 inline int64_t* INTEGER64(SEXP x) {
   return reinterpret_cast<int64_t*>(REAL(x));
